@@ -5,31 +5,50 @@ import pytest
 FILE_MODE = 0o754
 
 LOCAL_CLASS = "j2_Test+@-!^Class"
+LOCAL_CLASS2 = "j2_Test+@-|^2nd_Class withSpace"
+LOCAL_ARCH = "j2_Test+@-!^Arch"
 LOCAL_SYSTEM = "j2_Test+@-!^System"
 LOCAL_HOST = "j2_Test+@-!^Host"
 LOCAL_USER = "j2_Test+@-!^User"
 LOCAL_DISTRO = "j2_Test+@-!^Distro"
+LOCAL_DISTRO_FAMILY = "j2_Test+@-!^Family"
 TEMPLATE = f'''
 start of template
-j2 class  = >{{{{YADM_CLASS}}}}<
-j2 os     = >{{{{YADM_OS}}}}<
-j2 host   = >{{{{YADM_HOSTNAME}}}}<
-j2 user   = >{{{{YADM_USER}}}}<
-j2 distro = >{{{{YADM_DISTRO}}}}<
+j2 class         = >{{{{YADM_CLASS}}}}<
+j2 arch          = >{{{{YADM_ARCH}}}}<
+j2 os            = >{{{{YADM_OS}}}}<
+j2 host          = >{{{{YADM_HOSTNAME}}}}<
+j2 user          = >{{{{YADM_USER}}}}<
+j2 distro        = >{{{{YADM_DISTRO}}}}<
+j2 distro_family = >{{{{YADM_DISTRO_FAMILY}}}}<
+j2 classes = >{{{{YADM_CLASSES}}}}<
 {{%- if YADM_CLASS == "wrongclass1" %}}
 wrong class 1
 {{%- endif %}}
 {{%- if YADM_CLASS == "{LOCAL_CLASS}" %}}
-Included section for class = {{{{YADM_CLASS}}}} ({{{{YADM_CLASS}}}} repeated)
+Included j2 section for class = \
+{{{{YADM_CLASS}}}} ({{{{YADM_CLASS}}}} repeated)
 {{%- endif %}}
 {{%- if YADM_CLASS == "wrongclass2" %}}
 wrong class 2
 {{%- endif %}}
+{{%- if "{LOCAL_CLASS2}" in YADM_CLASSES.split("\\n") %}}
+Included j2 section for second class
+{{%- endif %}}
+{{%- if YADM_ARCH == "wrongarch1" %}}
+wrong arch 1
+{{%- endif %}}
+{{%- if YADM_ARCH == "{LOCAL_ARCH}" %}}
+Included j2 section for arch = {{{{YADM_ARCH}}}} ({{{{YADM_ARCH}}}} repeated)
+{{%- endif %}}
+{{%- if YADM_ARCH == "wrongarch2" %}}
+wrong arch 2
+{{%- endif %}}
 {{%- if YADM_OS == "wrongos1" %}}
 wrong os 1
 {{%- endif %}}
 {{%- if YADM_OS == "{LOCAL_SYSTEM}" %}}
-Included section for os = {{{{YADM_OS}}}} ({{{{YADM_OS}}}} repeated)
+Included j2 section for os = {{{{YADM_OS}}}} ({{{{YADM_OS}}}} repeated)
 {{%- endif %}}
 {{%- if YADM_OS == "wrongos2" %}}
 wrong os 2
@@ -38,7 +57,8 @@ wrong os 2
 wrong host 1
 {{%- endif %}}
 {{%- if YADM_HOSTNAME == "{LOCAL_HOST}" %}}
-Included section for host = {{{{YADM_HOSTNAME}}}} ({{{{YADM_HOSTNAME}}}} again)
+Included j2 section for host = \
+{{{{YADM_HOSTNAME}}}} ({{{{YADM_HOSTNAME}}}} again)
 {{%- endif %}}
 {{%- if YADM_HOSTNAME == "wronghost2" %}}
 wrong host 2
@@ -47,7 +67,7 @@ wrong host 2
 wrong user 1
 {{%- endif %}}
 {{%- if YADM_USER == "{LOCAL_USER}" %}}
-Included section for user = {{{{YADM_USER}}}} ({{{{YADM_USER}}}} repeated)
+Included j2 section for user = {{{{YADM_USER}}}} ({{{{YADM_USER}}}} repeated)
 {{%- endif %}}
 {{%- if YADM_USER == "wronguser2" %}}
 wrong user 2
@@ -56,25 +76,44 @@ wrong user 2
 wrong distro 1
 {{%- endif %}}
 {{%- if YADM_DISTRO == "{LOCAL_DISTRO}" %}}
-Included section for distro = {{{{YADM_DISTRO}}}} ({{{{YADM_DISTRO}}}} again)
+Included j2 section for distro = \
+{{{{YADM_DISTRO}}}} ({{{{YADM_DISTRO}}}} again)
 {{%- endif %}}
 {{%- if YADM_DISTRO == "wrongdistro2" %}}
 wrong distro 2
 {{%- endif %}}
+{{%- if YADM_DISTRO_FAMILY == "wrongfamily1" %}}
+wrong family 1
+{{%- endif %}}
+{{%- if YADM_DISTRO_FAMILY == "{LOCAL_DISTRO_FAMILY}" %}}
+Included j2 section for distro_family = \
+{{{{YADM_DISTRO_FAMILY}}}} ({{{{YADM_DISTRO_FAMILY}}}} again)
+{{%- endif %}}
+{{%- if YADM_DISTRO_FAMILY == "wrongfamily2" %}}
+wrong family 2
+{{%- endif %}}
 end of template
 '''
 EXPECTED = f'''
 start of template
-j2 class  = >{LOCAL_CLASS}<
-j2 os     = >{LOCAL_SYSTEM}<
-j2 host   = >{LOCAL_HOST}<
-j2 user   = >{LOCAL_USER}<
-j2 distro = >{LOCAL_DISTRO}<
-Included section for class = {LOCAL_CLASS} ({LOCAL_CLASS} repeated)
-Included section for os = {LOCAL_SYSTEM} ({LOCAL_SYSTEM} repeated)
-Included section for host = {LOCAL_HOST} ({LOCAL_HOST} again)
-Included section for user = {LOCAL_USER} ({LOCAL_USER} repeated)
-Included section for distro = {LOCAL_DISTRO} ({LOCAL_DISTRO} again)
+j2 class         = >{LOCAL_CLASS}<
+j2 arch          = >{LOCAL_ARCH}<
+j2 os            = >{LOCAL_SYSTEM}<
+j2 host          = >{LOCAL_HOST}<
+j2 user          = >{LOCAL_USER}<
+j2 distro        = >{LOCAL_DISTRO}<
+j2 distro_family = >{LOCAL_DISTRO_FAMILY}<
+j2 classes = >{LOCAL_CLASS2}
+{LOCAL_CLASS}<
+Included j2 section for class = {LOCAL_CLASS} ({LOCAL_CLASS} repeated)
+Included j2 section for second class
+Included j2 section for arch = {LOCAL_ARCH} ({LOCAL_ARCH} repeated)
+Included j2 section for os = {LOCAL_SYSTEM} ({LOCAL_SYSTEM} repeated)
+Included j2 section for host = {LOCAL_HOST} ({LOCAL_HOST} again)
+Included j2 section for user = {LOCAL_USER} ({LOCAL_USER} repeated)
+Included j2 section for distro = {LOCAL_DISTRO} ({LOCAL_DISTRO} again)
+Included j2 section for distro_family = \
+{LOCAL_DISTRO_FAMILY} ({LOCAL_DISTRO_FAMILY} again)
 end of template
 '''
 
@@ -97,10 +136,13 @@ def test_template_j2(runner, yadm, tmpdir, processor):
     script = f"""
         YADM_TEST=1 source {yadm}
         local_class="{LOCAL_CLASS}"
+        local_classes=("{LOCAL_CLASS2}" "{LOCAL_CLASS}")
+        local_arch="{LOCAL_ARCH}"
         local_system="{LOCAL_SYSTEM}"
         local_host="{LOCAL_HOST}"
         local_user="{LOCAL_USER}"
         local_distro="{LOCAL_DISTRO}"
+        local_distro_family="{LOCAL_DISTRO_FAMILY}"
         template_{processor} "{input_file}" "{output_file}"
     """
     run = runner(command=['bash'], inp=script)
